@@ -1287,8 +1287,15 @@ ev_view_presentation_update_monitor_geometry (EvViewPresentation *pview)
 	monitor = gdk_display_get_monitor_at_window (display, window);
 	gdk_monitor_get_geometry (monitor, &geometry);
 
+#if GTK_CHECK_VERSION(3, 24, 9)
+	/* See Evince issue #1365 and GTK regression gtk#2599 */
+	int scale_factor = gdk_monitor_get_scale_factor (monitor);
+	pview->monitor_width = geometry.width / scale_factor;
+	pview->monitor_height = geometry.height / scale_factor;
+#else
 	pview->monitor_width = geometry.width;
 	pview->monitor_height = geometry.height;
+#endif
 }
 
 static gboolean
